@@ -1,6 +1,9 @@
 import inspect
 from typing import Dict
+import logging
 
+_log = logging.getLogger(__name__)
+_DEBUG = False
 
 def call_callable_dynamic_args(func, *args, **kwargs):
     if not callable(func):
@@ -23,11 +26,17 @@ def call_callable_dynamic_args(func, *args, **kwargs):
     try:
         if spec.varkw:
             # inject the rest of kwargs if we have some left overs
+            if _DEBUG:
+                _log.debug(f"call {func}({call_args},{kwargs})")
+
             return func(*call_args, **kwargs)
         else:
+            if _DEBUG:
+                _log.debug(f"call {func}({kwargs})")
+
             return func(*call_args)
     except Exception as e:
-        raise RuntimeError(e, f"error while calling {func} whith arguments {call_args}")
+        raise RuntimeError(e, f"error while calling {func}({spec.args}) whith arguments {call_args}, {kwargs}")
 
 
 def suitable_kwargs(func, **kwargs):
